##
##  cmake.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major  3.31
%define       V_opkg   3.31.3
%define       V_dist   3.31.3

#   package information
Name:         cmake
Summary:      Cross-Platform Build System
URL:          http://cmake.org/
Vendor:       Kitware Inc., Insight Consortium
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Building
License:      MIT-style
Version:      %{V_opkg}
Release:      20241219

#   list of sources
Source0:      https://cmake.org/files/v%{V_major}/cmake-%{V_dist}.tar.gz
Patch0:       cmake.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    CMake is an extensible, open-source system that manages the build
    process in an operating system and compiler independent manner.
    Unlike many cross-platform systems, CMake is designed to be used in
    conjunction with the native build environment. Simple configuration
    files placed in each source directory (called CMakeLists.txt files)
    are used to generate standard build files (e.g., makefiles on Unix
    and projects/workspaces in Windows MSVC) which are used in the usual
    way. CMake can compile source code, create libraries, generate
    wrappers, and build executables in arbitrary combinations. CMake
    supports in-place and out-of-place builds, and can therefore support
    multiple builds from a single source tree. CMake also supports
    static and dynamic library builds. Another nice feature of CMake is
    that it generates a cache file that is designed to be used with a
    graphical editor. For example, when CMake runs, it locates include
    files, libraries, and executable, and may encounter optional build
    directives. This information is gathered into the cache, which may
    be changed by the user prior to the generation of the native build
    files.

%track
    prog cmake = {
        version   = %{V_dist}
        url       = https://github.com/Kitware/CMake/releases/
        regex     = tree/v(\d+\.\d+(?:\.\d+))
    }

%prep
    %setup -q -n cmake-%{V_dist}
    %patch -p0

%build
    %{l_shtool} subst \
        -e 's;/usr/local;%{l_prefix};g' \
        Modules/*.cmake
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O} -D__BSD_VISIBLE" \
    CXXFLAGS="%{l_cxxflags -O} -D__BSD_VISIBLE" \
    ./configure \
        --prefix=%{l_prefix} \
        --datadir=/share/cmake \
        --docdir=/share/cmake/doc
    %{l_make} %{l_mflags}

%install
    bin/cmake -D CMAKE_INSTALL_PREFIX=$RPM_BUILD_ROOT%{l_prefix} -P cmake_install.cmake
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/cmake/doc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/cmake/Help
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

